package trmpj;

import java.util.HashSet;
import java.util.Set;

/**
 * 対戦者を結びつけるペアクラス
 * @author furuta
 *
 */
public class TPair {

    /**
     * ペアID
     */
    private String pairId;

    /**
     * 同一のユーザIDがいないかのフラグ
     */
    private boolean isDuplicated;

    /**
     * 準備ができたかのフラグ
     */
    private boolean isPrepared;

    /**
     * ゲームが終了したかのフラグ
     */
    private boolean ended;

    /**
     * 管理するセッション
     */
    private Set<TSession> sessions;

    /**
     * コンストラクタ
     * @param pairId
     */
    public TPair(String pairId) {
        this.pairId = pairId;
        this.isDuplicated = false;
        this.isPrepared = false;
        this.ended = false;
        this.sessions = new HashSet<TSession>();
    }

    /**
     * ユーザIDが重複していないか
     * @return boolean
     */
    public boolean isDuplicated() {
        return isDuplicated;
    }

    /**
     * セッションが残っているか
     * @return boolean
     */
    public boolean isEmpty() {
        if (sessions.size() > 0) {
            return false;
        }
        return true;
    }

    /**
     * セッションを追加する
     * @param session
     */
    public void addTSession(TSession session) {
        // 同一ユーザIDチェック
        for (TSession s : sessions) {
            if (s.getUser().userId.equals(session.getUser().userId)) {
                isDuplicated = true;
                return;
            }
        }

        // 追加
        if (!sessions.contains(session)) {
            sessions.add(session);
        }

        // セッションに2名以上格納されたら準備できたものとする
        if (sessions.size() >= 2) {
            isPrepared = true;
        }
    }

    /**
     * 入っているユーザ情報を返す
     * @return Set<TUser>
     */
    public Set<TUser> getUsers() {
        Set<TUser> users = new HashSet<TUser>();
        for (TSession s : sessions) {
            users.add(s.getUser());
        }
        return users;
    }

    /**
     * メッセージを送る
     * @param res
     */
    public void sendMessage(TRes res) {
        for (TSession s : sessions) {
            s.sendMessage(res);
        }
    }

    /**
     * 準備ができたかを判定する
     * @return boolean
     */
    public boolean isPrepared() {
        return isPrepared;
    }

    /**
     * セッションを削除する
     * @param session
     */
    public void removeTSession(TSession session) {
        sessions.remove(session);
    }

    /**
     * ゲームが終了しているか
     * @return boolean
     */
    public boolean isEnded() {
        return ended;
    }

    /**
     * ゲームの終了状態をセットする
     * @param ended
     */
    public void setEnded(boolean ended) {
        this.ended = ended;
    }

    /**
     * ペアIDを返す
     * @return String
     */
    public String getPairId() {
        return pairId;
    }
}
