package trmpj;

import javax.websocket.Session;

import com.google.gson.Gson;
import com.google.gson.JsonSyntaxException;

/**
 * websocketセッションをラッパーしたクラス
 * @author furuta
 *
 */
public class TSession {

    /**
     * websocketセッション
     */
    private Session session;

    /**
     * ユーザ情報
     */
    private TUser user;

    /**
     * コンストラクタ
     * @param session
     */
    public TSession(Session session) {
        this.session = session;
    }

    /**
     * メッセージを解析して、オブジェクトに落とし込む
     * @param message
     * @param cls
     * @return <T> T
     */
    @SuppressWarnings("unchecked")
    public <T> T receiveMessage(String message, Class<? extends TReq> cls) {
        try {
            return (T) new Gson().fromJson(message, cls);
        } catch (JsonSyntaxException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * メッセージを送信する
     * @param res
     */
    public void sendMessage(TRes res) {
        try {
            String message = new Gson().toJson(res);
            if (session.isOpen()) {
                session.getBasicRemote().sendText(message);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * ユーザ情報を取得する
     * @return TUser
     */
    public TUser getUser() {
        return user;
    }

    /**
     * ユーザ情報を格納する
     * @param user
     */
    public void setUser(TUser user) {
        this.user = user;
    }
}
